############################
Interstellar Dust Extinction
############################

``dust_extinction`` is a python package to provide interstellar dust extinction
curves.

While there are other python packages that provide some of the extinction
curves contained here, the explicit motivation for this package is to provide
extinction curves to those using them to model/correct their data and those
studying extinction curves directly to better undertand interstellar dust.

This package is developed in the 
`astropy affiliated package <http://www.astropy.org/affiliated/>`_ 
template and uses the 
`astropy.modeling <http://docs.astropy.org/en/stable/modeling/>`_ 
framework.

Installation
============

To be added

User Documenation
=================

.. toctree::
   :maxdepth: 2

   Flavors of Models <dust_extinction/model_flavors.rst>
   Extinguish (or unextinguish) data <dust_extinction/extinguish.rst>
   Fitting extinction curves <dust_extinction/fit_extinction.rst>
   
              
Reporting Issues
================

If you have found a bug in ``dust_extinction`` please report it by creating a
new issue on the ``dust_extinction`` `GitHub issue tracker
<https://github.com/karllark/dust_extinction/issues>`_.

Please include an example that demonstrates the issue sufficiently so that
the developers can reproduce and fix the problem. You may also be asked to
provide information about your operating system and a full Python
stack trace.  The developers will walk you through obtaining a stack
trace if it is necessary.

Contributing
============

Like the `Astropy`_ project, ``dust_extinction`` is made both by and for its
users.  We accept contributions at all levels, spanning the gamut from
fixing a typo in the documentation to developing a major new feature.
We welcome contributors who will abide by the `Python Software
Foundation Code of Conduct
<https://www.python.org/psf/codeofconduct/>`_.

``dust_extinction`` follows the same workflow and coding guidelines as
`Astropy`_.  The following pages will help you get started with
contributing fixes, code, or documentation (no git or GitHub
experience necessary):

* `How to make a code contribution <http://astropy.readthedocs.io/en/stable/development/workflow/development_workflow.html>`_

* `Coding Guidelines <http://docs.astropy.io/en/latest/development/codeguide.html>`_

* `Try the development version <http://astropy.readthedocs.io/en/stable/development/workflow/get_devel_version.html>`_

* `Developer Documentation <http://docs.astropy.org/en/latest/#developer-documentation>`_


For the complete list of contributors please see the `dust_extinction
contributors page on Github
<https://github.com/karllark/dust_extinction/graphs/contributors>`_.

Reference API
=============
.. toctree::
   :maxdepth: 1

   dust_extinction/reference_api.rst

